%define major		2
%define libname		%mklibname xml2_ %{major}
%define develname	%mklibname xml2 -d

Summary:	Library providing XML and HTML support
Name:		libxml2
# WARNING: Please rebuild perl-XML-LibXML when you upload a new version else
#          you'll break a ton of perl packages' testsuite!!!!!
Version:	2.10.4
%define subrel 3
Release:	%mkrel 1
License:	MIT
Group: 		System/Libraries
URL:		http://www.xmlsoft.org/
Source0:	https://download.gnome.org/sources/%{name}/2.10/%{name}-%{version}.tar.xz
# Patch from openSUSE.
# See:  https://bugzilla.gnome.org/show_bug.cgi?id=789714
Patch1:         libxml2-2.9.8-python3-unicode-errors.patch
Patch2:         d0c3f01e110d54415611c5fa0040cdf4a56053f9.patch
Patch3:         235b15a590eecf97b09e87bdb7e4f8333e9de129.patch
Patch4:         d39f78069dff496ec865c73aa44d7110e429bce9.patch
Patch5:         2b0aac140d739905c7848a42efc60bfe783a39b7.patch

BuildRequires:	gtk-doc
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(liblzma)
BuildRequires:	pkgconfig(readline)

%description
This library allows you to manipulate XML files. It includes support
for reading, modifying and writing XML and HTML files. There is DTDs
support: this includes parsing and validation even with complex DtDs,
either at parse time or later once the document has been modified. The
output can be a simple SAX stream or and in-memory DOM-like
representations. In this case one can use the built-in XPath and
XPointer implementation to select subnodes or ranges. A flexible
Input/Output mechanism is available, with existing HTTP and FTP modules
and combined to a URI library.

%package -n	%{libname}
Summary:	Shared libraries providing XML and HTML support
Group: 		System/Libraries
Obsoletes:	%{mklibname xml 2} < 2.9.10
Provides:	%{name} = %{version}-%{release}

%description -n	%{libname}
This library allows you to manipulate XML files. It includes support
for reading, modifying and writing XML and HTML files. There is DTDs
support: this includes parsing and validation even with complex DtDs,
either at parse time or later once the document has been modified.

%package	utils
Summary:	Utilities to manipulate XML files
Group:		System/Libraries
Provides:	xmllint = %{version}-%{release}
Provides:	xmlcatalog = %{version}-%{release}

%description	utils
This packages contains utils to manipulate XML files.

%package	python3
Summary:	Python bindings for the libxml2 library
Group:		Development/Python
Requires:	python3 >= %{python3_version}
Provides:	python3-%{name} = %{version}-%{release}
%{?python_provide:%python_provide python3-%{name}}

%description	python3
The libxml2-python3 package contains a module that permits applications
written in the Python programming language to use the interface
supplied by the libxml2 library to manipulate XML files.

This library allows you to manipulate XML files. It includes support
for reading, modifying and writing XML and HTML files. There is DTDs
support: this includes parsing and validation even with complex DtDs,
either at parse time or later once the document has been modified.

%package -n	%{develname}
Summary:	Libraries, includes, etc. to develop XML and HTML applications
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
Libraries, include files, etc you can use to develop XML applications.
This library allows you to manipulate XML files. It includes support
for reading, modifying and writing XML and HTML files. There is DTDs
support: this includes parsing and validation even with complex DtDs,
either at parse time or later once the document has been modified.

%prep
%setup -q
%autopatch -p1

# Prep py3 docs
mkdir py3doc
cp doc/*.py py3doc
sed -i 's|#!/usr/bin/python |#!%{__python3} |' py3doc/*.py

# Remove files generated by python/generator.py to force regenerating them
# rm python/{libxml2-py.c,libxml2-py.h,libxml2-export.c}

%build
autoreconf -vfi
%configure --disable-static
%make_build

%install
%make_install

#only do it here if check aren't done
if [ %{_with check} -eq 0 ]; then
  # clean before packaging documentation
  (cd doc/examples ; make clean ; rm -rf .deps Makefile)
  gzip -9 doc/libxml2-api.xml
fi


# multiarch policy
%multiarch_binaries %{buildroot}%{_bindir}/xml2-config

# remove unpackaged files
rm -rf	%{buildroot}%{_prefix}/doc \
 	%{buildroot}%{_datadir}/doc

#we don't want these
find %{buildroot} -name "*.la" -delete

%check
# all tests must pass
# use TARBALLURL_2="" TARBALLURL="" TESTDIRS="" to disable xstc test which are using remote tarball
make TARBALLURL_2="" TARBALLURL="" TESTDIRS="" check

#need to do that after check otherwise it will fail
# clean before packaging documentation
(cd doc/examples ; make clean ; rm -rf .deps Makefile)
gzip -9 doc/libxml2-api.xml

%files -n %{libname}
%{_libdir}/lib*.so.%{major}{,.*}

%files utils
%doc README.md TODO
%license Copyright
%{_bindir}/xmlcatalog
%{_bindir}/xmllint
%{_mandir}/man1/xmlcatalog*
%{_mandir}/man1/xmllint*

%files python3
%doc README.md TODO
%license Copyright
%doc py3doc/*.py
%doc python/TODO
%doc python/libxml2class.txt
%doc python/tests/*.py
%{python3_sitearch}/*
%{python3_sitelib}/*


%files -n %{develname}
%doc NEWS README.md TODO
%license Copyright
#doc doc/*.html doc/*.gif doc/*.png doc/html doc/examples doc/tutorial
%doc doc/libxml2-api.xml.gz
%doc %{_datadir}/gtk-doc/html/*
%{_bindir}/xml2-config
%multiarch %{multiarch_bindir}/xml2-config
%{_libdir}/*.so
#{_libdir}/*.sh
%{_libdir}/pkgconfig/*
%{_libdir}/cmake/libxml2/libxml2-config.cmake
%{_mandir}/man1/xml2-config*
#{_mandir}/man3/*
%{_includedir}/*
%{_datadir}/aclocal/*


%changelog
* Mon May 06 2024 ns80 <ns80> 2.10.4-1.3.mga9
+ Revision: 2062544
- add an upstream patch for CVE-2024-25062 (mga#33184)
- backport upstream patch for CVE-2023-45322 (mga#32364)
- add upstream patches for CVE-2023-39615 (mga#32304)

* Sun Apr 23 2023 daviddavid <daviddavid> 2.10.4-1.mga9
+ Revision: 1954482
- new version 2.10.4
- remove merged upstream patches

* Wed Apr 19 2023 ns80 <ns80> 2.10.3-2.mga9
+ Revision: 1953616
- add upstream patches for CVE-2023-28484 and CVE-2023-29469 (mga#31810)

* Wed Nov 02 2022 ns80 <ns80> 2.10.3-1.mga9
+ Revision: 1901622
- new version 2.10.3 for CVE-2022-4030[34] (mga#31020)
+ ghibo <ghibo>
- Fix URL of Source0

* Sun Oct 09 2022 neoclust <neoclust> 2.10.2-1.mga9
+ Revision: 1895906
- New version 2.10.2

* Mon May 02 2022 ovitters <ovitters> 2.9.14-1.mga9
+ Revision: 1855470
- new version 2.9.14

* Fri Mar 18 2022 umeabot <umeabot> 2.9.13-2.mga9
+ Revision: 1797890
- Mageia 9 Mass Rebuild

* Sat Feb 26 2022 luigiwalser <luigiwalser> 2.9.13-1.mga9
+ Revision: 1785578
- 2.9.13
- update source URL
- remove upstream patch

* Sat Feb 26 2022 ns80 <ns80> 2.9.12-3.mga9
+ Revision: 1785355
- add upstream patch for CVE-2022-23308 (mga#30094)

* Sat Feb 12 2022 tv <tv> 2.9.12-2.mga9
+ Revision: 1773520
- Rebuild for python-3.10

* Tue Jun 01 2021 ns80 <ns80> 2.9.12-1.mga9
+ Revision: 1729104
- new version 2.9.12 for CVE-2021-3541 (mga#29039)

* Wed May 12 2021 ns80 <ns80> 2.9.10-9.mga9
+ Revision: 1722577
- add Fedora patches for CVE-2021-351[6-8] and CVE-2021-3537 (mga#28902)

* Mon Mar 15 2021 wally <wally> 2.9.10-8.mga9
+ Revision: 1703110
- add python fixes from Fedora
- rebuild for python 3.9

* Thu Jan 28 2021 neoclust <neoclust> 2.9.10-7.mga8
+ Revision: 1673838
- Add P9: Fix a segfault

* Sun Dec 27 2020 luigiwalser <luigiwalser> 2.9.10-6.mga8
+ Revision: 1664288
- add patches from fedora to fix CVE-2020-24977

* Wed Jun 10 2020 shlomif <shlomif> 2.9.10-5.mga8
+ Revision: 1591684
- mga#26753 - revert CVE-2019-19956

* Wed Apr 01 2020 danf <danf> 2.9.10-4.mga8
+ Revision: 1563898
- Drop Python 2 support
+ shlomif <shlomif>
- security: patch for MGA#26222; cve-2019-20388

* Thu Feb 20 2020 shlomif <shlomif> 2.9.10-3.mga8
+ Revision: 1547369
- security: patch for MGA#26222; other patch was already applied

* Tue Feb 18 2020 umeabot <umeabot> 2.9.10-2.mga8
+ Revision: 1539610
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Dec 09 2019 shlomif <shlomif> 2.9.10-1.mga8
+ Revision: 1465370
- New version 2.9.10

* Mon Sep 16 2019 tv <tv> 2.9.9-7.mga8
+ Revision: 1441978
- reintroduce python2 subpkg (too much pain for now)

* Thu Sep 05 2019 tv <tv> 2.9.9-6.mga8
+ Revision: 1437483
- submit to core/updates_testing

* Thu Sep 05 2019 tv <tv> 2.9.9-5.mga8
+ Revision: 1437461
- drop python2 submodule
- use python_provide
- submit to core/updates_testin

* Wed Sep 04 2019 tv <tv> 2.9.9-4.mga8
+ Revision: 1437361
- fix generating SRPM: drop version from requires on python2 (we have 2.7 for a long time anyway...)
- BR python
- rebuild for python 3.8

* Fri Aug 09 2019 tv <tv> 2.9.9-3.mga8
+ Revision: 1428408
- Add patch to fix crash: xmlParserPrintFileContextInternal mangles utf8

* Tue Jan 08 2019 tv <tv> 2.9.9-2.mga7
+ Revision: 1352100
- rebuild with python 3.7

* Fri Jan 04 2019 shlomif <shlomif> 2.9.9-1.mga7
+ Revision: 1349130
- New version 2.9.9

* Sun Sep 23 2018 umeabot <umeabot> 2.9.8-3.mga7
+ Revision: 1299259
- Mageia 7 Mass Rebuild

* Sun May 06 2018 wally <wally> 2.9.8-2.mga7
+ Revision: 1226700
- provide xmlcatalog

* Sun Apr 22 2018 shlomif <shlomif> 2.9.8-1.mga7
+ Revision: 1221236
- New version 2.9.8

* Wed Dec 27 2017 luigiwalser <luigiwalser> 2.9.7-2.mga7
+ Revision: 1185838
- try without patch (breaks test suite)
- forward port opensuse patch for CVE-2017-8872
- remove patches (fixed differently upstream)

* Fri Nov 03 2017 shlomif <shlomif> 2.9.7-1.mga7
+ Revision: 1175674
- New version 2.9.7

* Fri Oct 06 2017 shlomif <shlomif> 2.9.6-1.mga7
+ Revision: 1169481
- New version 2.9.6

* Sat Aug 05 2017 pterjan <pterjan> 2.9.4-9.mga7
+ Revision: 1135264
- Rebuild for python 3.6

* Fri Jul 07 2017 akien <akien> 2.9.4-8.mga6
+ Revision: 1109384
- Run autoreconf to fix automake 1.15 vs 1.15.1 version mismatch (duh...)
+ luigiwalser <luigiwalser>
- resync patches for CVE-2017-904[7-9] and CVE-2017-9050 with opensuse
- add patches from opensuse to fix CVE-2017-7375 and CVE-2017-7376

* Sat Jul 01 2017 luigiwalser <luigiwalser> 2.9.4-7.mga6
+ Revision: 1108886
- add patches from opensuse to fix CVE-2017-0663 and CVE-2017-5969
- drop libxml2-NULL-deref-xmlDumpElementContent.patch, like opensuse did

* Sun Jun 04 2017 ngompa <ngompa> 2.9.4-6.mga6
+ Revision: 1106745
- Add python 3 bindings

* Sun Jun 04 2017 luigiwalser <luigiwalser> 2.9.4-5.mga6
+ Revision: 1106623
- sync patches from debian and opensuse to fix security issues (mga#19695)
+ neoclust <neoclust>
- Fix CVE-2016-4658
+ tv <tv>
- add a big fat warning about rebuilding perl-XML-LibXML on new version upload!

* Fri Jul 22 2016 shlomif <shlomif> 2.9.4-4.mga6
+ Revision: 1043158
- Patch was already applied upstream

* Fri Jul 22 2016 shlomif <shlomif> 2.9.4-3.mga6
+ Revision: 1043147
- Remove a patch that was fixed upstream differently and add new patch.

* Fri Jul 22 2016 shlomif <shlomif> 2.9.4-2.mga6
+ Revision: 1043140
- New patch from RHEL/CentOS

* Wed Jul 20 2016 luigiwalser <luigiwalser> 2.9.4-1.mga6
+ Revision: 1042929
- 2.9.4
- rediff CVE-2016-3627 patch
- remove upstreamed CVE-2016-3705 patch

* Wed May 18 2016 luigiwalser <luigiwalser> 2.9.3-3.mga6
+ Revision: 1016804
- add patches suggested upstream to fix CVE-2016-3627 and CVE-2016-3705

* Thu Dec 24 2015 wally <wally> 2.9.3-2.mga6
+ Revision: 914029
- drop unneeded obsoletes
- add provides for xmllint to libxml2-utils
- drop unneeded lib requires

* Fri Nov 20 2015 shlomif <shlomif> 2.9.3-1.mga6
+ Revision: 904486
- New version 2.9.3
+ luigiwalser <luigiwalser>
- add upstream patch to fix CVE-2015-8241

* Tue Nov 03 2015 luigiwalser <luigiwalser> 2.9.2-5.mga6
+ Revision: 897548
- add upstream patch to fix CVE-2015-8035

* Mon Oct 26 2015 luigiwalser <luigiwalser> 2.9.2-4.mga6
+ Revision: 895607
- add upstream patch to fix CVE-2015-7942

* Wed Sep 02 2015 luigiwalser <luigiwalser> 2.9.2-3.mga6
+ Revision: 872198
- add patch to fix bdo#782985 (aka bgo#746048)

* Fri Aug 21 2015 tmb <tmb> 2.9.2-2.mga6
+ Revision: 867777
- rebuild for new gcc

* Sat Jul 04 2015 luigiwalser <luigiwalser> 2.9.2-1.mga6
+ Revision: 850618
- 2.9.2
- remove CVE-2014-3660 patch (fixed upstream)
- remove CVE-2014-0191 and related patches (fixed upstream)
- add patch from fedora to fix rhbz#1153753
- add upstream patch to fix CVE-2015-1819
- add upstream patches to fix bgo#744980 aka bdo#783010

* Mon Feb 09 2015 luigiwalser <luigiwalser> 2.9.1-11.mga5
+ Revision: 814454
- add upstream patch to fix regression from CVE-2014-3660 fix (bgo#738805)

* Fri Oct 17 2014 luigiwalser <luigiwalser> 2.9.1-10.mga5
+ Revision: 776681
- add upstream patch to fix CVE-2014-3660
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 2.9.1-8.mga5
+ Revision: 726927
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 2.9.1-7.mga5
+ Revision: 681889
- Mageia 5 Mass Rebuild

* Tue Jun 17 2014 luigiwalser <luigiwalser> 2.9.1-6.mga5
+ Revision: 637833
- add patch from ubuntu to fix regression in xmllint from CVE-2014-0191 fix

* Sat May 31 2014 pterjan <pterjan> 2.9.1-5.mga5
+ Revision: 628315
- Rebuild for new Python

* Wed May 28 2014 luigiwalser <luigiwalser> 2.9.1-4.mga5
+ Revision: 627227
- add patch from opensuse to fix regression in xmllint from CVE-2014-0191 fix

* Wed May 07 2014 luigiwalser <luigiwalser> 2.9.1-3.mga5
+ Revision: 621048
- add upstream patch to fix CVE-2014-0191

* Sat Oct 19 2013 umeabot <umeabot> 2.9.1-2.mga4
+ Revision: 523758
- Mageia 4 Mass Rebuild

* Fri May 24 2013 luigiwalser <luigiwalser> 2.9.1-1.mga4
+ Revision: 426841
- remove upstreamed patches
- 2.9.1

* Fri Apr 19 2013 luigiwalser <luigiwalser> 2.9.0-5.mga3
+ Revision: 410476
- add upstream patch to fix CVE-2013-1969 and CVE-2013-1970

* Fri Mar 01 2013 luigiwalser <luigiwalser> 2.9.0-4.mga3
+ Revision: 400903
- add upstream patch to fix CVE-2013-0338

* Sat Jan 12 2013 umeabot <umeabot> 2.9.0-3.mga3
+ Revision: 358621
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Nov 30 2012 luigiwalser <luigiwalser> 2.9.0-2.mga3
+ Revision: 323478
- add upstream patch to fix CVE-2012-5134

* Wed Sep 19 2012 oden <oden> 2.9.0-1.mga3
+ Revision: 296158
- 2.9.0
- drop the upstream added security patch

* Wed Aug 08 2012 luigiwalser <luigiwalser> 2.8.0-2.mga3
+ Revision: 280006
- add patch to fix CVE-2012-2807 (from debian via mdv)

* Sun Jun 03 2012 luigiwalser <luigiwalser> 2.8.0-1.mga3
+ Revision: 253520
- 2.8.0
- remove upstreamed patch

* Mon May 28 2012 luigiwalser <luigiwalser> 2.7.8-15.20120229.1.mga3
+ Revision: 247714
- add patch to fix CVE-2011-3102 (from ubuntu)

* Sun Mar 04 2012 fwang <fwang> 2.7.8-14.20120229.1.mga2
+ Revision: 217785
- update file list
- new upstream snapshot to avoid future cve patches

* Thu Feb 23 2012 dmorgan <dmorgan> 2.7.8-14.mga2
+ Revision: 212625
- Add P7: CVE-2012-0841 ( mga #4634)

* Sat Jan 14 2012 fwang <fwang> 2.7.8-13.mga2
+ Revision: 195862
- add upstream patch to fix CVE-2011-3919

* Thu Dec 15 2011 wally <wally> 2.7.8-12.mga2
+ Revision: 182318
- sync with mdv
  o fixes CVE-2011-0216
  o fixes CVE-2011-3905

* Sun Oct 09 2011 wally <wally> 2.7.8-11.mga2
+ Revision: 153547
- fix CVE-2011-1944 and CVE-2011-2821,2834 (thx Oden/Mdv)
- disable static build and get rid of .la files
- clean .spec a bit

* Tue Jul 12 2011 wally <wally> 2.7.8-10.mga2
+ Revision: 123111
- add lib major check to filelist
- rebuild to get higher rel than in Mageia 1

* Fri May 06 2011 ahmad <ahmad> 2.7.8-9.mga1
+ Revision: 95274
- Revert the deleting of .la files

* Thu May 05 2011 ahmad <ahmad> 2.7.8-8.mga1
+ Revision: 95203
- Don't ship .la files

* Sun Jan 16 2011 pterjan <pterjan> 2.7.8-7.mga1
+ Revision: 20630
- Rebuild for python 2.7

* Wed Jan 12 2011 ahmad <ahmad> 2.7.8-6.mga1
+ Revision: 6990
- drop old/unneeded scriptlets
- imported package libxml2


* Wed Dec 29 2010 Oden Eriksson <oeriksson@mandriva.com> 2.7.8-5mdv2011.0
+ Revision: 626025
- P1: security fix for CVE-2010-4494 (upstream)

* Tue Dec 28 2010 Funda Wang <fwang@mandriva.org> 2.7.8-4mdv2011.0
+ Revision: 625595
- more specific requires

* Tue Dec 28 2010 Funda Wang <fwang@mandriva.org> 2.7.8-3mdv2011.0
+ Revision: 625494
- revert version script per upstream

* Mon Dec 27 2010 Funda Wang <fwang@mandriva.org> 2.7.8-2mdv2011.0
+ Revision: 625370
- rebuild

  + Oden Eriksson <oeriksson@mandriva.com>
    - 2.7.8

* Wed Mar 17 2010 Frederic Crozat <fcrozat@mandriva.com> 2.7.7-1mdv2011.0
+ Revision: 524077
- Release 2.7.7

* Sun Mar 14 2010 Oden Eriksson <oeriksson@mandriva.com> 2.7.6-2mdv2010.1
+ Revision: 519031
- rebuild

* Mon Oct 12 2009 Frederic Crozat <fcrozat@mandriva.com> 2.7.6-1mdv2010.0
+ Revision: 456837
- Release 2.7.6
- Remove patches 3 & 4 (merged upstream)

* Tue Sep 15 2009 Frederic Crozat <fcrozat@mandriva.com> 2.7.4-2mdv2010.0
+ Revision: 443121
- Patch4 (GIT): fix inkscape crash (GNOME bug #566012)

* Fri Sep 11 2009 Frederic Crozat <fcrozat@mandriva.com> 2.7.4-1mdv2010.0
+ Revision: 438471
- Remove the old trick of generating optimisation at build time
- Release 2.7.4
- Remove patches 2, 4 (merged upstream)
- Regenerate patch3
- Change the way examples are cleaned to be nice with check pass

* Wed Aug 12 2009 Oden Eriksson <oeriksson@mandriva.com> 2.7.3-3mdv2010.0
+ Revision: 415502
- P4: security fix for CVE-2009-2414 and CVE-2009-2416

* Mon Jan 26 2009 Funda Wang <fwang@mandriva.org> 2.7.3-2mdv2009.1
+ Revision: 333661
- fix linkage of python module

* Tue Jan 20 2009 Götz Waschk <waschk@mandriva.org> 2.7.3-1mdv2009.1
+ Revision: 331728
- update the patch again
- update patch 2
- new version
- drop patches 0,1

* Thu Dec 25 2008 Funda Wang <fwang@mandriva.org> 2.7.2-4mdv2009.1
+ Revision: 318621
- rebuild for new python

* Thu Dec 18 2008 Oden Eriksson <oeriksson@mandriva.com> 2.7.2-3mdv2009.1
+ Revision: 315644
- added P2 to fix build with -Werror=format-security

* Thu Nov 27 2008 Frederic Crozat <fcrozat@mandriva.com> 2.7.2-2mdv2009.1
+ Revision: 307285
- Patches 0, 1 (SVN) : security fixes CVE-2008-4225, CVE-2008-4226

* Sun Oct 12 2008 Funda Wang <fwang@mandriva.org> 2.7.2-1mdv2009.1
+ Revision: 292782
- New version 2.7.2

* Mon Sep 01 2008 Frederic Crozat <fcrozat@mandriva.com> 2.7.1-1mdv2009.0
+ Revision: 278458
- Release 2.7.1
- Remove patch0 (merged upstream)

* Tue Aug 26 2008 Frederic Crozat <fcrozat@mandriva.com> 2.6.32-3mdv2009.0
+ Revision: 276261
- Patch0 (SVN): fix CVE-2008-3281

* Wed Aug 06 2008 Thierry Vignaud <tv@mandriva.org> 2.6.32-2mdv2009.0
+ Revision: 265004
- rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Thu Apr 10 2008 Götz Waschk <waschk@mandriva.org> 2.6.32-1mdv2009.0
+ Revision: 192542
- new version

* Mon Jan 28 2008 Adam Williamson <awilliamson@mandriva.org> 2.6.31-1mdv2008.1
+ Revision: 158960
- drop patch (merged upstream)
- new release 2.6.31

* Fri Jan 04 2008 Stefan van der Eijk <stefan@mandriva.org> 2.6.30-3mdv2008.1
+ Revision: 144924
- rebuild to fix error: unpacking of archive failed on file /usr/share/doc/lib64xml2-devel/libxml2-api.xml.gz;477e5e00: cpio: read

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Thu Nov 15 2007 Frederic Crozat <fcrozat@mandriva.com> 2.6.30-2mdv2008.1
+ Revision: 108908
- Update tarball with official version
- Update patch0 with improved version for upstream integration (GNOME bug #497012)
- Fix url for source0

* Tue Sep 18 2007 Götz Waschk <waschk@mandriva.org> 2.6.30-1mdv2008.0
+ Revision: 89538
- new version

* Wed Aug 15 2007 Anssi Hannula <anssi@mandriva.org> 2.6.29-4mdv2008.0
+ Revision: 63684
- obsolete renamed python bindings on lib64 archs

* Wed Aug 15 2007 Adam Williamson <awilliamson@mandriva.org> 2.6.29-3mdv2008.0
+ Revision: 63593
- lib package provides libxml2 for now, think about it later
- drop docs from library package
- use autoreconf instead of calling bits of it manually
- clean up descriptions
- python package should follow %%name, not %%libname
- new devel policy
- correct libification (libxml2_2 is the correct name for the lib package)
- clean up a bunch of conditionals for really old versions, no longer needed

* Fri Jul 06 2007 Frederic Crozat <fcrozat@mandriva.com> 2.6.29-1mdv2008.0
+ Revision: 49147
- Release 2.6.29

* Mon Apr 23 2007 Olivier Blin <oblin@mandriva.com> 2.6.28-1mdv2008.0
+ Revision: 17345
- 2.6.28 (and rebuild for missing devel package on x86_64)


* Mon Mar 19 2007 Thierry Vignaud <tvignaud@mandriva.com> 2.6.27-3mdv2007.1
+ Revision: 146578
- do not package big ChangeLog in -python

  + Helio Chissini de Castro <helio@mandriva.com>
    - Remove old source

* Tue Nov 28 2006 Götz Waschk <waschk@mandriva.org> 2.6.27-2mdv2007.1
+ Revision: 88048
- rebuild

* Sat Oct 28 2006 Götz Waschk <waschk@mandriva.org> 2.6.27-1mdv2007.1
+ Revision: 73543
- new version
- fix source URL

  + Oden Eriksson <oeriksson@mandriva.com>
    - bzip2 cleanup
    - rebuild
    - bunzip patches
    - Import libxml2

* Wed Jun 21 2006 Frederic Crozat <fcrozat@mandriva.com> 2.6.26-2mdv2007.0
- Fix doc (Mdv bug #19007)

* Thu Jun 08 2006 Frederic Crozat <fcrozat@mandriva.com> 2.6.26-1mdv2007.0
- Release 2.6.26

* Wed Jun 07 2006 Götz Waschk <waschk@mandriva.org> 2.6.25-1mdv2007.0
- New release 2.6.25

* Sat Apr 29 2006 Götz Waschk <waschk@mandriva.org> 2.6.24-1mdk
- New release 2.6.24

* Thu Jan 05 2006 Götz Waschk <waschk@mandriva.org> 2.6.23-1mdk
- New release 2.6.23
- use mkrel

* Wed Nov 16 2005 Frederic Crozat <fcrozat@mandriva.com> 2.6.22-2mdk
- Rebuild to get debug package

* Wed Oct 05 2005 Frederic Crozat <fcrozat@mandriva.com> 2.6.22-1mdk
- Release 2.6.22
- Remove patch2 (merged upstream)

* Wed Sep 14 2005 Frederic Crozat <fcrozat@mandriva.com> 2.6.21-3mdk 
- Update patch2 to fix clash with expat headers

* Tue Sep 13 2005 Frederic Crozat <fcrozat@mandriva.com> 2.6.21-2mdk 
- Patch2 (CVS): various fixes

* Tue Sep 06 2005 Frederic Crozat <fcrozat@mandriva.com> 2.6.21-1mdk 
- Release 2.6.21

* Thu Aug 25 2005 Frederic Crozat <fcrozat@mandriva.com> 2.6.20-3mdk 
- Remove changelog from main package to reduce its size

* Thu Aug 25 2005 Frederic Crozat <fcrozat@mandriva.com> 2.6.20-2mdk 
- Move api documentation to devel package

* Wed Jul 20 2005 Frederic Crozat <fcrozat@mandriva.com> 2.6.20-1mdk 
- New release 2.6.20
- Disable profiling, it doesn't work with gcc 4

* Tue Apr 19 2005 Frederic Crozat <fcrozat@mandriva.com> 2.6.19-1mdk 
- Release 2.6.19

* Thu Feb 24 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.6.17-2mdk
- multiarch for xml2-config --libtool-libs

* Tue Jan 18 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 2.6.17-1mdk
- New release 2.6.17

* Sun Dec 05 2004 Michael Scherer <misc@mandrake.org> 2.6.16-2mdk
- Rebuild for new python

* Wed Nov 10 2004 Goetz Waschk <waschk@linux-mandrake.com> 2.6.16-1mdk
- New release 2.6.16

* Tue Oct 19 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.6.14-1mdk
- New release 2.6.14
- Drop support for Mdk version < 9.2
- Remove patch 2 (no longer needed)

* Wed Sep 01 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.6.13-1mdk
- New release 2.6.13

* Tue Aug 24 2004 Götz Waschk <waschk@linux-mandrake.com> 2.6.12-1mdk
- patch 2 fixes the build
- New release 2.6.12

* Fri Jul 09 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.6.11-2mdk
- Integrate profiling stuff from Fedora (please report any problem)

* Wed Jul 07 2004 Goetz Waschk <waschk@linux-mandrake.com> 2.6.11-1mdk
- New release 2.6.11

* Wed Jun 02 2004 Guillaume Rousse <guillomovitch@mandrake.org> 2.6.10-1mdk
- new version

* Tue Apr 20 2004 Götz Waschk <waschk@linux-mandrake.com> 2.6.9-1mdk
- drop patch 2 (merged)
- new version

* Sat Apr 03 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.6.8-1mdk
- Release 2.6.8
- Patch2 (CVS): fix python tests

